@@ -8,15 +8,15 @@
 
   Drupal.behaviors.panels_ajax_tabs = {
     attach: function(context) {
-        $('.panels-ajax-tab-tab:not(.panels-ajax-tabs-processed)', context).once('panels-ajax-tabs-once', function() {  
+        $('.panels-ajax-tab-tab:not(.panels-ajax-tabs-processed)', context).once('panels-ajax-tabs-once', function() {
 
             //We need ot push the state when the page first loads, so we know what the first tab is
             if ($(this).parent().hasClass('active') && $(this).data('url-enabled') == 1) {
               if (typeof window.history.pushState != 'undefined') {
                 window.history.replaceState({'tab':$(this).data('panel-name')}, $(this).html(), $(this).attr('href'));
               }
-            } 
-            
+            }
+
             $(this).click(function(e) {
               e.preventDefault();
 
@@ -25,15 +25,15 @@
                 var href = $(this).attr('href') ? $(this).attr('href') : location.pathname;
                 window.history.pushState({'tab':$(this).data('panel-name')}, $(this).html(), href);
               }
-              
+
               if (!$(this).parent().hasClass('active')) {
                 $(this).panels_ajax_tabs_trigger();
               }
-              
+
             })
             .css('cursor', 'pointer')
             .addClass('panels-ajax-tabs-processed');
-  
+
         // Trigger a click event on the first tab to load it
         $('.pane-panels-ajax-tab-tabs', context).each(function() {
           var tabs = $('.panels-ajax-tab-tab:not(.panels-ajax-tabs-first-loaded)', this);
@@ -41,7 +41,7 @@
           var target_id = firstTab.data('target-id');
           var preloaded = $('#panels-ajax-tab-container-' + target_id).data('panels-ajax-tab-preloaded');
           var currentTab;
-          
+
           if (preloaded === '') {
             currentTab = firstTab;
             firstTab.trigger('click');
@@ -49,21 +49,21 @@
           else {
             currentTab = tabs.filter('*[data-panel-name="' + preloaded + '"]');
           }
-          
+
           currentTab.addClass('panels-ajax-tabs-first-loaded');
           currentTab.parent().addClass('active');
-        });  
+        });
       });
     }
   };
-  
+
 
   window.onpopstate = function(e) {
     if(e.state != null){
       $('a[data-panel-name="'+e.state.tab+'"]').panels_ajax_tabs_trigger();
     }
   };
-  
+
 })(jQuery);
 
 
@@ -77,11 +77,11 @@
       return this.each(function() {
         var $tab = $(this);
         var container = $tab.parents('.panels-ajax-tab:first');
-        
+
         // If it's already in the process of loading, don't do anything
         if ($(container).data('loading') === true) {
           return true;
-        }          
+        }
         $(container).data('loading', true);
 
         var target_id = $tab.data('target-id');
@@ -92,26 +92,26 @@
 
         // Create a few jQuery.Event events for a panel being loaded so that other code may hook into it
         var eventData = {
-          tab: this, 
+          tab: this,
           tabObject: $tab,
           containerId: '#panels-ajax-tab-container-' + target_id,
-          callback: callback, 
-          cache: false, 
+          callback: callback,
+          cache: false,
         }
         var preLoadEvent     = $.Event("panelsAjaxTabsPreLoad", eventData);      // We are about to do an ajax request. Will have data.cache = true if cache was used.
         var preBehaviorEvent = $.Event("panelsAjaxTabsPreBehavior", eventData);  // Content is loaded but behaviors have not fired. Not triggered when using cache.
         var loadedEvent      = $.Event("panelsAjaxTabsLoaded", eventData);       // Everything is done. Will have data.cache = true if cache was used.
-        
+
         // If we have it cached we don't need to do AJAX
         if ($('#panels-ajax-tab-container-' + target_id).children('.panels-ajax-tab-wrap-' + panel_name).length) {
           preLoadEvent.cached = true;
-          $(document).trigger(preLoadEvent, preLoadEvent.data);   
+          $(document).trigger(preLoadEvent, preLoadEvent.data);
 
           $('#panels-ajax-tab-container-' + target_id).children().hide();
           $('#panels-ajax-tab-container-' + target_id).children('.panels-ajax-tab-wrap-' + panel_name).show();
-          
+
           $(container).data('loading', false);
-          
+
           // Trigger optional callback
           if (callback) {
             callback.call(this, $tab);
@@ -119,18 +119,18 @@
 
           // Trigger jQuery Event
           loadedEvent.cached = true;
-          $(document).trigger(loadedEvent);            
+          $(document).trigger(loadedEvent);
         }
         else {
           // Do AJAX request
           $.ajax({
-            url: Drupal.settings.basePath + 'panels_ajax_tab/' + panel_name + '/' + entity_context + '/' + url_enabled + '?panels_ajax_tab_trigger=' + trigger,
+            url: Drupal.settings.basePath + 'panels_ajax_tab/' + panel_name + '/' + entity_context + '/' + url_enabled + '?panels_ajax_tab_trigger=' + trigger + '&panels_ajax_tab_tab=' + panel_name,
             datatype: 'html',
             headers: {"X-Request-Path": document.location.pathname},
-            cache: true,
+            cache: false,
             beforeSend: function(xhr) {
               // Trigger jQuery Event
-              $(document).trigger(preLoadEvent);   
+              $(document).trigger(preLoadEvent);
 
               // Hide content and show the spinning loading wheel
               $('#panels-ajax-tab-container-' + target_id).children().hide();
@@ -158,7 +158,7 @@
               callback.call(this, $tab);
             }
             // Trigger jQuery Event
-            $(document).trigger(loadedEvent);            
+            $(document).trigger(loadedEvent);
           })
         }
         $tab.parent().siblings().removeClass('active');
